==> django-ai-0.0.1a3.tar.gz: django-ai-0.0.1a3/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
import os
import re
import sys

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup


def get_version(*file_paths):
    """Retrieves the version from django_ai/__init__.py"""
    filename = os.path.join(os.path.dirname(__file__), *file_paths)
    version_file = open(filename).read()
    version_match = re.search(r"^__version__ = ['\"]([^'\"]*)['\"]",
                              version_file, re.M)
    if version_match:
        return version_match.group(1)
    raise RuntimeError('Unable to find version string.')


version = get_version("django_ai", "__init__.py")


if sys.argv[-1] == 'publish':
    try:
        import wheel
        print("Wheel version: ", wheel.__version__)
    except ImportError:
        print('Wheel library missing. Please run "pip install wheel"')
        sys.exit()
    os.system('python setup.py sdist upload')
    os.system('python setup.py bdist_wheel upload')
    sys.exit()

if sys.argv[-1] == 'tag':
    print("Tagging the version on git:")
    os.system("git tag -a %s -m 'version %s'" % (version, version))
    os.system("git push --tags")
    sys.exit()

readme = open('README.rst').read()
history = open('HISTORY.rst').read().replace('.. :changelog:', '')

setup(
    name='django-ai',
    version=version,
    description="""Artificial Intelligence for Django""",
    long_description=readme + '\n\n' + history,
    author='Rodrigo Gadea',
    author_email='matematica.a3k@gmail.com',
    url='https://github.com/math-a3k/django-ai',
    packages=[
        'django_ai',
    ],
    include_package_data=True,
    install_requires=[
        'bayespy==0.5.6',
        'Django>=1.11, <2.0',
        'django-dag==1.4.1',
        'django-nested-admin==3.0.20',
        'django-picklefield==1.0.0',
        'graphviz==0.6',
        'Pillow==4.2.1',
    ],
    license="LGPLv3",
    zip_safe=False,
    keywords='django-ai',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Framework :: Django',
        'Framework :: Django :: 1.11',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Topic :: Scientific/Engineering :: Artificial Intelligence',
        'Topic :: Scientific/Engineering :: Mathematics',
        'Topic :: Software Development :: Libraries :: Application Frameworks',
    ],
)

==> django-ai-0.0.2.tar.gz: django-ai-0.0.2/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
import os
import re
import sys

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup


def get_version(*file_paths):
    """Retrieves the version from django_ai/__init__.py"""
    filename = os.path.join(os.path.dirname(__file__), *file_paths)
    version_file = open(filename).read()
    version_match = re.search(r"^__version__ = ['\"]([^'\"]*)['\"]",
                              version_file, re.M)
    if version_match:
        return version_match.group(1)
    raise RuntimeError('Unable to find version string.')


version = get_version("django_ai", "__init__.py")


if sys.argv[-1] == 'publish':
    try:
        import wheel
        print("Wheel version: ", wheel.__version__)
    except ImportError:
        print('Wheel library missing. Please run "pip install wheel"')
        sys.exit()
    os.system('python setup.py sdist upload')
    os.system('python setup.py bdist_wheel upload')
    sys.exit()

if sys.argv[-1] == 'tag':
    print("Tagging the version on git:")
    os.system("git tag -a %s -m 'version %s'" % (version, version))
    os.system("git push --tags")
    sys.exit()

readme = open('README.rst').read()

setup(
    name='django-ai',
    version=version,
    description="""Artificial Intelligence for Django""",
    long_description=readme,
    author='Rodrigo Gadea',
    author_email='matematica.a3k@gmail.com',
    url='https://github.com/math-a3k/django-ai',
    packages=[
        'django_ai',
    ],
    include_package_data=True,
    install_requires=[
        'bayespy==0.5.6',
        'Django>=1.11, <2.1',
        'django-nested-admin==3.0.20',
        'django-picklefield==1.0.0',
        'graphviz==0.6',
        'jsonfield==2.0.2',
        'Pillow==4.2.1',
        'scikit-learn>=0.19.1',
    ],
    license="LGPLv3",
    zip_safe=False,
    keywords='django-ai',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Framework :: Django',
        'Framework :: Django :: 1.11',
        'Intended Audience :: Developers',
        ('License :: OSI Approved :: '
         'GNU Lesser General Public License v3 or later (LGPLv3+)'),
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Topic :: Scientific/Engineering :: Artificial Intelligence',
        'Topic :: Scientific/Engineering :: Mathematics',
        'Topic :: Software Development :: Libraries :: Application Frameworks',
    ],
)
